@@ -7,6 +7,7 @@ import logging
 import sys
 import traceback
 import urllib2
+import uuid
 
 from django.core.cache import cache
 from django.template import TemplateSyntaxError
@@ -22,6 +23,20 @@ class SentryClient(object):
     def process(self, **kwargs):
         from sentry.helpers import get_filters
 
+        request = kwargs.pop('request', None)
+        if request:
+            if not kwargs.get('data'):
+                kwargs['data'] = {}
+            kwargs['data'].update(dict(
+                META=request.META,
+                POST=request.POST,
+                GET=request.GET,
+                COOKIES=request.COOKIES,
+            ))
+
+            if not kwargs.get('url'):
+                kwargs['url'] = request.build_absolute_uri()
+
         kwargs.setdefault('level', logging.ERROR)
         kwargs.setdefault('server_name', conf.NAME)
 
@@ -39,13 +54,18 @@ class SentryClient(object):
             parts = kwargs['view'].split('.')
             module_list = ['.'.join(parts[:idx]) for idx in xrange(1, len(parts)+1)][::-1]
             version = None
+            module = None
             for m in module_list:
                 if m in versions:
+                    module = m
                     version = versions[m]
 
             # store our "best guess" for application version
             if version:
-                kwargs['data']['__sentry__']['version'] = version
+                kwargs['data']['__sentry__'].update({
+                    'version': version,
+                    'module': module,
+                })
 
         if 'checksum' not in kwargs:
             checksum = construct_checksum(**kwargs)
@@ -69,10 +89,16 @@ class SentryClient(object):
         for filter_ in get_filters():
             kwargs = filter_(None).process(kwargs) or kwargs
         
+        # create ID client-side so that it can be passed to application
+        message_id = uuid.uuid4().hex
+        kwargs['message_id'] = message_id
+
         # Make sure all data is coerced
         kwargs = transform(kwargs)
 
-        return self.send(**kwargs)
+        self.send(**kwargs)
+        
+        return message_id
 
     def send(self, **kwargs):
         if conf.REMOTE_URL:
@@ -101,24 +127,10 @@ class SentryClient(object):
         """
         Creates an error log for a `logging` module `record` instance.
         """
-        for k in ('url', 'view', 'data'):
+        for k in ('url', 'view', 'data', 'request'):
             if k not in kwargs:
                 kwargs[k] = record.__dict__.get(k)
         
-        request = getattr(record, 'request', None)
-        if request:
-            if not kwargs.get('data'):
-                kwargs['data'] = {}
-            kwargs['data'].update(dict(
-                META=request.META,
-                POST=request.POST,
-                GET=request.GET,
-                COOKIES=request.COOKIES,
-            ))
-
-            if not kwargs.get('url'):
-                kwargs['url'] = request.build_absolute_uri()
-        
         kwargs.update({
             'logger': record.name,
             'level': record.levelno,
