@@ -3,7 +3,6 @@ from django.db.models import Count
 from django.utils import simplejson
 from django.template.defaultfilters import stringfilter
 
-from sentry.helpers import get_db_engine
 from sentry.plugins import GroupActionProvider
 
 import datetime
@@ -57,7 +56,7 @@ def chart_data(group, max_days=90):
     method = conn.ops.date_trunc_sql('hour', 'datetime')
 
     chart_qs = list(group.message_set.all()\
-                      .filter(datetime__gte=datetime.datetime.now() - datetime.timedelta(hours=hours))\
+                      .filter(datetime__gte=today - datetime.timedelta(hours=hours))\
                       .extra(select={'grouper': method}).values('grouper')\
                       .annotate(num=Count('id')).values_list('grouper', 'num')\
                       .order_by('grouper'))
@@ -65,34 +64,22 @@ def chart_data(group, max_days=90):
     if not chart_qs:
         return {}
 
-    min_date = chart_qs[0][0]
-    if min_date and min_date < datetime.datetime.now() - datetime.timedelta(days=1):
-        stop_hours = (datetime.datetime.now() - min_date).days * 24
-        start_hours = (datetime.datetime.now() - chart_qs[-1][0]).days * 24
-    else:
-        stop_hours = 24
-        start_hours = 0
-    
     rows = dict(chart_qs)
-    if rows:
-        max_y = max(rows.values())
-    else:
-        max_y = 1
     
     return {
-        'points': [rows.get(today-datetime.timedelta(hours=d), 0) for d in xrange(start_hours, stop_hours)][::-1],
-        'categories': [str(today-datetime.timedelta(hours=d)) for d in xrange(start_hours, stop_hours)][::-1],
+        'points': [rows.get(today-datetime.timedelta(hours=d), 0) for d in xrange(hours, 0, -1)],
+        'categories': [str(today-datetime.timedelta(hours=d)) for d in xrange(hours, 0, -1)],
     }
 
 @register.filter
 def to_json(data):
     return simplejson.dumps(data)
 
+@register.simple_tag
 def sentry_version():
     import sentry
     
     return sentry.VERSION
-register.simple_tag(sentry_version)
 
 @register.filter
 def get_actions(group, request):
