@@ -1,10 +1,11 @@
-import logging
 import base64
 try:
     import cPickle as pickle
 except ImportError:
     import pickle
 import datetime
+import logging
+import re
 import zlib
 
 from django.core.context_processors import csrf
@@ -20,11 +21,13 @@ from django.views.decorators.csrf import csrf_protect, csrf_exempt
 
 from sentry import conf
 from sentry.helpers import get_filters
-from sentry.models import GroupedMessage
+from sentry.models import GroupedMessage, Message
 from sentry.plugins import GroupActionProvider
 from sentry.templatetags.sentry_helpers import with_priority
 from sentry.reporter import ImprovedExceptionReporter
 
+uuid_re = re.compile(r'^[a-z0-9]{32}$')
+
 def get_search_query_set(query):
     from haystack.query import SearchQuerySet
     from sentry.search_indexes import site, backend
@@ -35,8 +38,11 @@ def get_search_query_set(query):
         def __getitem__(self, k):
             result = []
             for r in super(SentrySearchQuerySet, self).__getitem__(k):
-                r.object.score = r.score
-                result.append(r.object)
+                inst = r.object
+                if not inst:
+                    continue
+                inst.score = r.score
+                result.append(inst)
             return result
     
     return SentrySearchQuerySet(
@@ -99,6 +105,15 @@ def index(request):
     is_search = query
 
     if is_search:
+        if uuid_re.match(query):
+            # Forward to message if it exists
+            try:
+                message = Message.objects.get(message_id=query)
+            except Message.DoesNotExist:
+                pass
+            else:
+                return HttpResponseRedirect(message.get_absolute_url())
+
         message_list = get_search_query_set(query)
     else:
         message_list = GroupedMessage.objects.extra(
@@ -234,8 +249,14 @@ def ajax_handler(request):
 def group(request, group_id):
     group = get_object_or_404(GroupedMessage, pk=group_id)
 
-    obj = group.message_set.all().order_by('-id')[0]
-    if '__sentry__' in obj.data:
+    try:
+        obj = group.message_set.all().order_by('-id')[0]
+    except IndexError:
+        # It's possible that a message would not be created under certain circumstances
+        # (such as a post_save signal failing)
+        obj = Message(group=group, data=group.data)
+
+    if '__sentry__' in obj.data and 'exc' in obj.data['__sentry__']:
         module, args, frames = obj.data['__sentry__']['exc']
         obj.class_name = str(obj.class_name)
         # We fake the exception class due to many issues with imports/builtins/etc
@@ -246,8 +267,11 @@ def group(request, group_id):
     
         reporter = ImprovedExceptionReporter(obj.request, exc_type, exc_value, frames, obj.data['__sentry__'].get('template'))
         traceback = mark_safe(reporter.get_traceback_html())
+        version_data = obj.data['__sentry__'].get('versions', {}).iteritems()
+
     elif group.traceback:
         traceback = mark_safe('<pre>%s</pre>' % (group.traceback,))
+        version_data = None
     
     def iter_data(obj):
         for k, v in obj.data.iteritems():
@@ -277,7 +301,7 @@ def group_message_details(request, group_id, message_id):
 
     message = get_object_or_404(group.message_set, pk=message_id)
     
-    if '__sentry__' in message.data:
+    if '__sentry__' in message.data and 'exc' in message.data['__sentry__']:
         module, args, frames = message.data['__sentry__']['exc']
         message.class_name = str(message.class_name)
         # We fake the exception class due to many issues with imports/builtins/etc
